/*******************************************************************************
 * Licensed Materials - Property of IBM
 * "Restricted Materials of IBM"
 *
 *     Copyright IBM Corp. 2001, 2014 All Rights Reserved
 *
 * US Government Users Restricted Rights - Use, duplication or disclosure
 * restricted by GSA ADP Schedule Contract with IBM Corp.
 *******************************************************************************/
package javax.rcm;

import java.util.concurrent.Executors;

/**
 * The signal generator for thread consumer
 */
class ThreadCPUSignalGenerator extends AbstractCPUSignalGenerator {

	public ThreadCPUSignalGenerator(long interval) {
		super(interval);
	}

	@Override
	protected void signalCpuThrottling() {
		Thread currentThread = Thread.currentThread();
		for(Thread t : getThreads()){
			if(null != t && t != currentThread)
				signalAsyncEvent(t, throttlingRunnable);
		}
	}

	private Thread[] getThreads() {
		ThreadGroup group = Thread.currentThread().getThreadGroup();
		ThreadGroup parent = group.getParent();
		while(null != parent){
			group = parent;
			parent = group.getParent();
		}

		Thread[] threads = new Thread[group.activeCount()];
		group.enumerate(threads);
		return threads;
	}

	@Override
	protected Thread newThread() {
		return Executors.defaultThreadFactory().newThread(this);
	}
}
